# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__PROJECT__ = 'tw.mochikit'
__DESCRIPTION__ = 'MochiKit 1.4 (dev) widget for ToscaWidgets'
__URL__ = 'http://toscawidgets.org'
__VERSION__ = '0.8'
__AUTHOR__ = 'Alberto Valverde Gonzalez'
__EMAIL__ = "alberto@toscat.net"
__COPYRIGHT__ = "Copyright 2006 Alberto Valverde Gonzalez"
__LICENSE__ = 'MIT'



"""
MochiKit 1.4 widget for ToscaWidgets

To download and install::

  easy_install twMochiKit

"""

from tw.api import JSLink, js_function

__all__ = [
    "mochikit",
    "packed",
    "base",
    "iter",
    "async",
    "dom",
    "signal",
    "datetime",
    "format",
    "style",
    ]

base = JSLink(
    modname = __name__, 
    filename = 'static/Base.js',
    )

datetime = JSLink(
    modname = __name__, 
    filename = 'static/DateTime.js',
    )

format = JSLink(
    modname = __name__, 
    filename = 'static/Format.js',
    )

async = JSLink(
    modname = __name__, 
    filename = 'static/Async.js',
    javascript = [base]
    )

iter = JSLink(
    modname = __name__, 
    filename = 'static/Iter.js',
    javascript = [base]
    )

dom = JSLink(
    modname = __name__, 
    filename = 'static/DOM.js',
    javascript = [base]
    )

signal = JSLink(
    modname = __name__, 
    filename = 'static/Signal.js',
    javascript = [base, dom]
    )

style = JSLink(
    modname = __name__, 
    filename = 'static/Style.js',
    javascript = [base, dom]
    )


packed = JSLink(
    modname = __name__, 
    filename = 'static/packed/MochiKit.js',
    )

mochikit = JSLink(
    modname = __name__, 
    filename = 'static/MochiKit.js',
    )

connect = js_function('MochiKit.Signal.connect')
